summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/stdtransactiondownloaded.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/stdtransactiondownloaded.h')
-rw-r--r--kmymoney2/widgets/stdtransactiondownloaded.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kmymoney2/widgets/stdtransactiondownloaded.h b/kmymoney2/widgets/stdtransactiondownloaded.h
index 705fb04..0320882 100644
--- a/kmymoney2/widgets/stdtransactiondownloaded.h
+++ b/kmymoney2/widgets/stdtransactiondownloaded.h
@@ -38,7 +38,7 @@ namespace KMyMoneyRegister {
class StdTransactionDownloaded : public StdTransaction
{
public:
- StdTransactionDownloaded(Register* parent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
+ StdTransactionDownloaded(Register* tqparent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
virtual ~StdTransactionDownloaded() {}
virtual const char* className(void) { return "StdTransactionDownloaded"; }
@@ -55,28 +55,28 @@ public:
* - textRect (area covering the text)
* - color of the pen to do the painting of text and lines
*
* @param painter pointer to the QPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
* @param cellRect ref to QRect object receiving the area information for the cell
* @param textRect ref to QRect object receiving the area information for the text
* @param cg ref to QColorGroup object receiving the color information to be used
* @param brush ref to QBrush object receiveing the brush information to be used
*/
- virtual bool paintRegisterCellSetup(QPainter* painter, int& row, int& col, QRect& cellRect, QRect& textRect, QColorGroup& cg, QBrush& brush);
+ virtual bool paintRegisterCellSetup(TQPainter* painter, int& row, int& col, TQRect& cellRect, TQRect& textRect, TQColorGroup& cg, TQBrush& brush);
#if 0
- virtual void paintRegisterCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg);
+ virtual void paintRegisterCell(TQPainter* painter, int row, int col, const TQRect& r, bool selected, const TQColorGroup& cg);
- bool formCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
- void registerCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
+ bool formCellText(TQString& txt, int& align, int row, int col, TQPainter* painter = 0);
+ void registerCellText(TQString& txt, int& align, int row, int col, TQPainter* painter = 0);
int numColsForm(void) const { return 4; }
- void arrangeWidgetsInForm(QMap<QString, QWidget*>& editWidgets);
- void arrangeWidgetsInRegister(QMap<QString, QWidget*>& editWidgets);
- void tabOrderInForm(QWidgetList& tabOrderWidgets) const;
- void tabOrderInRegister(QWidgetList& tabOrderWidgets) const;
+ void arrangeWidgetsInForm(TQMap<TQString, TQWidget*>& editWidgets);
+ void arrangeWidgetsInRegister(TQMap<TQString, TQWidget*>& editWidgets);
+ void tabOrderInForm(TQWidgetList& tabOrderWidgets) const;
+ void tabOrderInRegister(TQWidgetList& tabOrderWidgets) const;
int numRowsRegister(bool expanded) const;
#endif
@@ -90,7 +90,7 @@ public:
class InvestTransactionDownloaded : public InvestTransaction
{
public:
- InvestTransactionDownloaded(Register* parent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
+ InvestTransactionDownloaded(Register* tqparent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
virtual ~InvestTransactionDownloaded() {}
virtual const char* className(void) { return "InvestTransactionDownloaded"; }
@@ -107,15 +107,15 @@ class InvestTransactionDownloaded : public InvestTransaction
* - textRect (area covering the text)
* - color of the pen to do the painting of text and lines
*
* @param painter pointer to the QPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
* @param cellRect ref to QRect object receiving the area information for the cell
* @param textRect ref to QRect object receiving the area information for the text
* @param cg ref to QColorGroup object receiving the color information to be used
* @param brush ref to QBrush object receiveing the brush information to be used
*/
- virtual bool paintRegisterCellSetup(QPainter* painter, int& row, int& col, QRect& cellRect, QRect& textRect, QColorGroup& cg, QBrush& brush);
+ virtual bool paintRegisterCellSetup(TQPainter* painter, int& row, int& col, TQRect& cellRect, TQRect& textRect, TQColorGroup& cg, TQBrush& brush);
/**
* Provided for internal reasons. No API change. See RegisterItem::numRowsRegister()
*/
@@ -55,28 +55,28 @@ public:
* - color of the pen to do the painting of text and lines
*
- * @param painter pointer to the QPainter object
+ * @param painter pointer to the TQPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
@@ -55,28 +55,28 @@ public:
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
- * @param cellRect ref to QRect object receiving the area information for the cell
- * @param textRect ref to QRect object receiving the area information for the text
- * @param cg ref to QColorGroup object receiving the color information to be used
- * @param brush ref to QBrush object receiveing the brush information to be used
+ * @param cellRect ref to TQRect object receiving the area information for the cell
+ * @param textRect ref to TQRect object receiving the area information for the text
+ * @param cg ref to TQColorGroup object receiving the color information to be used
+ * @param brush ref to TQBrush object receiveing the brush information to be used
*/
@@ -107,15 +107,15 @@ class InvestTransactionDownloaded : public InvestTransaction
* - color of the pen to do the painting of text and lines
*
- * @param painter pointer to the QPainter object
+ * @param painter pointer to the TQPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
@@ -107,15 +107,15 @@ class InvestTransactionDownloaded : public InvestTransaction
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
- * @param cellRect ref to QRect object receiving the area information for the cell
- * @param textRect ref to QRect object receiving the area information for the text
- * @param cg ref to QColorGroup object receiving the color information to be used
- * @param brush ref to QBrush object receiveing the brush information to be used
+ * @param cellRect ref to TQRect object receiving the area information for the cell
+ * @param textRect ref to TQRect object receiving the area information for the text
+ * @param cg ref to TQColorGroup object receiving the color information to be used
+ * @param brush ref to TQBrush object receiveing the brush information to be used
*/